pub unsafe fn set_enabled(mask: Interrupts)Expand description
Replace IE with mask.
Safety
Introduces preemption, breaking code that assumes interrupts stay off.
pub unsafe fn set_enabled(mask: Interrupts)Replace IE with mask.
Introduces preemption, breaking code that assumes interrupts stay off.